conan-index-tools tool
======================

The ``conan-index-tools`` helps with the process of preparing the Pull Request to the ``conan-center-index`` repository.
You can install it running ``pip install conan-index-tools``. 

Read more at the `Conan center index repository <https://github.com/conan-io/conan_index>`_



